from natural.constant import _, _multi
import datetime


# Wed, 02 Oct 2002 08:00:00 EST
# Wed, 02 Oct 2002 13:00:00 GMT
# Wed, 02 Oct 2002 15:00:00 +0200
RFC2822_DATETIME_FORMAT = '%a, %d %b %Y %T %z'
# Wed, 02 Oct 02 08:00:00 EST
# Wed, 02 Oct 02 13:00:00 GMT
# Wed, 02 Oct 02 15:00:00 +0200
RFC822_DATETIME_FORMAT  = '%a, %d %b %y %T %z'
# 2012-06-13T15:24:17
ISO8601_DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S'
# Wed, 02 Oct 2002
RFC2822_DATE_FORMAT     = '%a, %d %b %Y'
# Wed, 02 Oct 02
RFC822_DATE_FORMAT      = '%a, %d %b %y'
# 2012-06-13
ISO8601_DATE_FORMAT     = '%Y-%m-%d'

# Precalculated timestamps
TIME_MINUTE             = 60
TIME_HOUR               = 3600
TIME_DAY                = 86400
TIME_WEEK               = 604800


def _to_datetime(t):
    '''
    Internal function that tries whatever to convert ``t`` into a
    :class:`datetime.datetime` object.
    '''

    if isinstance(t, float) or \
        isinstance(t, int) or \
        isinstance(t, long):
        return datetime.datetime.fromtimestamp(float(t))

    elif isinstance(t, basestring):
        for format in (
            RFC2822_DATETIME_FORMAT,
            RFC822_DATETIME_FORMAT,
            ISO8601_DATETIME_FORMAT,
            ):
            try:
                return datetime.datetime.strptime(t, format)
            except ValueError:
                pass

        raise ValueError('Format not supported')

    elif isinstance(t, datetime.datetime):
        return t

    elif isinstance(t, datetime.date):
        return datetime.datetime.combine(t, datetime.time(0, 0))

    else:
        raise TypeError


def _to_date(t):
    '''
    Internal function that tries whatever to convert ``t`` into a
    :class:`datetime.date` object.
    '''

    if isinstance(t, float) or \
        isinstance(t, int) or \
        isinstance(t, long):
        return datetime.date.fromtimestamp(float(t))

    elif isinstance(t, basestring):
        for format in (
            RFC2822_DATE_FORMAT,
            RFC822_DATE_FORMAT,
            ISO8601_DATE_FORMAT,
            ):
            try:
                return datetime.datetime.strptime(t, format).date()
            except ValueError:
                pass

        raise ValueError('Format not supported')

    elif isinstance(t, datetime.datetime):
        return t.date()

    elif isinstance(t, datetime.date):
        return t

    else:
        raise TypeError


def delta(t1, t2, words=True, justnow=datetime.timedelta(seconds=10)):
    '''
    Calculates the estimated delta between two time objects in human-readable
    format. Used internally by the :func:`day` and :func:`duration` functions.

    :param t1: timestamp, :class:`datetime.date` or :class:`datetime.datetime`
               object
    :param t2: timestamp, :class:`datetime.date` or :class:`datetime.datetime`
               object
    '''

    t1 = _to_datetime(t1)
    t2 = _to_datetime(t2)
    diff = t1 - t2

    # The datetime module includes milliseconds with float precision. Floats
    # will give unexpected results here, so we round the value here
    total = int(diff.total_seconds() + 0.5)

    if abs(total) < TIME_DAY:
        if diff < justnow and words:
            return (
                _(u'just now'),
                0,
            )

        elif abs(total) < TIME_MINUTE:
            seconds = abs(total)
            return (
                _multi(
                    _(u'%d second'),
                    _(u'%d seconds'),
                seconds) % (seconds,),
                0,
            )
        elif abs(total) < TIME_MINUTE * 2 and words:
            return (
                _(u'a minute'),
                0,
            )

        elif abs(total) < TIME_HOUR:
            minutes, seconds = divmod(abs(total), TIME_MINUTE)
            if total < 0: seconds *= -1
            return (
                _multi(
                    _(u'%d minute'),
                    _(u'%d minutes'),
                minutes) % (minutes,),
                seconds,
            )

        elif abs(total) < TIME_HOUR * 2 and words:
            return (
                _(u'an hour'),
                0,
            )

        else:
            hours, seconds = divmod(abs(total), TIME_HOUR)
            if total < 0: seconds *= -1

            return (
                _multi(
                    _(u'%d hour'),
                    _(u'%d hours'),
                hours) % (hours,),
                seconds,
            )

    elif abs(total) < TIME_DAY * 2 and words:
        if total > 0:
            return (_(u'tomorrow'), 0)
        else:
            return (_(u'yesterday'), 0)

    elif abs(total) < TIME_WEEK:
        days, seconds = divmod(abs(total), TIME_DAY)
        if total < 0: seconds *= -1
        return (
            _multi(
                _(u'%d day'),
                _(u'%d days'),
            days) % (days,),
            seconds,
        )

    elif abs(diff.days) == TIME_WEEK and words:
        if total > 0:
            return (_(u'next week'), diff.seconds)
        else:
            return (_(u'last week'), diff.seconds)

# FIXME
#
# The biggest reliable unit we can supply to the user is a week (for now?),
# because we can not safely determine the amount of days in the covered
# month/year span.

    else:
        weeks, seconds = divmod(abs(total), TIME_WEEK)
        if total < 0: seconds *= -1
        return (
            _multi(
                _(u'%d week'),
                _(u'%d weeks'),
            weeks) % (weeks,),
            seconds,
        )


def day(t, now=None, format='%B %d'):
    '''
    Date delta compared to ``t``. You can override ``now`` to specify what date
    to compare to.

    You can override the date format by supplying a ``format`` parameter.

    :param t: timestamp, :class:`datetime.date` or :class:`datetime.datetime`
              object
    :param now: default ``None``, optionally a :class:`datetime.datetime`
                object
    :param format: default ``'%B %d'``
    '''
    t1 = _to_date(t)
    t2 = _to_date(now or datetime.datetime.now())
    diff = t1 - t2
    secs = diff.total_seconds()

    if diff.days == 0:
        return _(u'today')
    elif diff.days == 1:
        if secs < 0:
            return _(u'yesterday')
        else:
            return _(u'tomorrow')
    elif diff.days == 7:
        if secs < 0:
            return _(u'last week')
        else:
            return _(u'next week')
    else:
        return t1.strftime(format)


def duration(t, now=None, precision=1, pad=u', ', words=None):
    '''
    Time delta compared to ``t``. You can override ``now`` to specify what time
    to compare to.

    :param t: timestamp, :class:`datetime.date` or :class:`datetime.datetime`
              object
    :param now: default ``None``, optionally a :class:`datetime.datetime`
                object
    :param precision: default ``1``, number of fragments to return
    :param words: default ``None``, allow words like "yesterday", if set to
                  ``None`` this will be enabled if ``precision`` is set to
                  ``1``
    '''

    if words is None:
        words = precision == 1

    t1 = _to_datetime(t)
    t2 = _to_datetime(now or datetime.datetime.now())

    if t1 < t2:
        format = _(u'%s ago')
    else:
        format = _(u'%s from now')

    result, remains = delta(t1, t2, words=words)
    if result in (
        _(u'just now'),
        _(u'yesterday'), _(u'tomorrow'),
        _(u'last week'), _(u'next week'),
        ):
        return result

    elif precision > 1 and remains:
        t3 = t2 - datetime.timedelta(seconds=remains)
        return pad.join([
            result,
            duration(t2, t3, precision - 1, pad, words=False),
        ])

    else:
        return format % (result,)


def compress(t, sign=False, pad=u''):
    '''
    Convert the input to compressed format, works with a
    :class:`datetime.timedelta` object or a number that represents the number
    of seconds you want to compress.  If you supply a timestamp or a
    :class:`datetime.datetime` object, it will give the delta relative to the
    current time.

    You can enable showing a sign in front of the compressed format with the
    ``sign`` parameter, the default is not to show signs.

    Optionally, you can chose to pad the output. If you wish your values to be
    separated by spaces, set ``pad`` to ``' '``.

    :param t: seconds or :class:`datetime.timedelta` object
    :param sign: default ``False``
    :param pad: default ``u''``
    '''

    if isinstance(t, datetime.timedelta):
        seconds = t.seconds + (t.days * 86400)
    elif isinstance(t, float) or isinstance(t, int) or isinstance(t, long):
        seconds = long(t)
    else:
        return compress(datetime.datetime.now() - _to_datetime(t), sign, pad)

    parts = []
    if sign:
        parts.append(u'-' if t.days < 0 else u'+')

    weeks, seconds   = divmod(seconds, TIME_WEEK)
    days, seconds    = divmod(seconds, TIME_DAY)
    hours, seconds   = divmod(seconds, TIME_HOUR)
    minutes, seconds = divmod(seconds, TIME_MINUTE)

    if weeks:
        parts.append(_(u'%dw') % (weeks,))
    if days:
        parts.append(_(u'%dd') % (days,))
    if hours:
        parts.append(_(u'%dh') % (hours,))
    if minutes:
        parts.append(_(u'%dm') % (minutes,))
    if seconds:
        parts.append(_(u'%ds') % (seconds,))

    return pad.join(parts)



import locale
from natural.constant import FILESIZE_SUFFIX
from natural.number import _format

FILESIZE_BASE = dict(
    decimal=1024,
    binary=1000,
    gnu=1024,
)


def filesize(value, format='decimal', digits=2):
    '''
    Convert a file size into natural readable format. Multiple formats are
    supported.

    :param value: size
    :param format: default ``decimal``, choices ``binary``, ``decimal`` or
                   ``gnu``
    :param digits: default ``2``
    '''

    if not format in FILESIZE_SUFFIX:
        raise TypeError

    base = FILESIZE_BASE[format]
    size = long(value)
    sign = size < 0 and u'-' or ''
    size = abs(size)

    for i, suffix in enumerate(FILESIZE_SUFFIX[format]):
        unit = base ** (i + 1)
        if size < unit:
            result = u''.join([
                sign,
                _format(base * size / float(unit), digits),
                u' ',
                suffix,
            ])
            if format == 'gnu':
                result = result.replace(' ', '')
            return result

    raise OverflowError


def decimalsize(value):
    '''
    Wrapper for :py:func:`filesize`.
    '''
    return filesize(value, format='decimal')


def binarysize(value):
    '''
    Wrapper for :py:func:`filesize`.
    '''
    return filesize(value, format='binary')


def gnusize(value, digits=1):
    '''
    Wrapper for :py:func:`filesize`.
    '''
    return filesize(value, format='gnu', digits=digits)



# -*- coding: utf-8 -*-
import gettext
import locale
import os


'''
.. py:attribute:: LOCALE_PATH

   Path on the file system to the locale/ directory, used to find translations
   for the current locale.


.. py:attribute:: CONVENTION

   Container for all the locale conventions, see
   http://docs.python.org/library/locale.html#locale.localeconv


.. py:attribute:: ORDINAL_SUFFIX

   Suffixes for the ordinal number representation.


.. py:attribute:: LARGE_NUMBER_SUFFIX

   Suffixes for the word number representation.


.. py:attribute:: FILESIZE_SUFFIX

   Suffixes for the file size representations.


.. py:function:: _(message)

   Return the localised translation of ``message``, based on the current global
   domain, language, and locale directory.


.. py:function:: _multi(singular, plural, count)

   Return the localised translation based on ``count``, the ``singular``
   version if ``count == 1``, the ``plural`` version otherwise.

'''


locale.setlocale(locale.LC_ALL, '')

LOCALE_PATH = os.path.join(os.path.dirname(__file__), 'locale')
gettext.bindtextdomain('natural', LOCALE_PATH)
gettext.textdomain('natural')
try:
    TRANSLATION = gettext.translation('natural', LOCALE_PATH)
    _ = TRANSLATION.ugettext
except IOError:
    _ = gettext.NullTranslations().ugettext

# generic
CONVENTION = locale.localeconv()
# natural.number
ORDINAL_SUFFIX = (
    _(u'th'),
    _(u'st'),
    _(u'nd'),
    _(u'rd'),
    _(u'th'),
    _(u'th'),
    _(u'th'),
    _(u'th'),
    _(u'th'),
    _(u'th'),
)
LARGE_NUMBER_SUFFIX = (
    _(u'thousand'),
    _(u'million'),
    _(u'billion'),
    _(u'trillion'),
    _(u'quadrillion'),
    _(u'quintillion'),
    _(u'sextillion'),
    _(u'septillion'),
    _(u'octillion'),
    _(u'nonillion'),
    _(u'decillion'),
    _(u'undecillion'),
    _(u'duodecillion'),
    _(u'tredecillion'),
    _(u'quattuordecillion'),
    _(u'quindecillion'),
    _(u'sexdecillion'),
    _(u'septendecillion'),
    _(u'octodec'),
    _(u'novemdecillion'),
    _(u'vigintillion'),
    _(u'unvigintillion'),
    _(u'duovigintil'),
    _(u'tresvigintillion'),
    _(u'quattuorvigintillion'),
    _(u'quinquavigintillion'),
    _(u'sesvigintillion'),
    _(u'septemvigintillion'),
    _(u'octovigintillion'),
    _(u'novemvigintillion'),
    _(u'trigintillion'),
    _(u'untrigintillion'),
    _(u'duotrigintillion'),
    _(u'trestrigintillion'),
    _(u'quattuortrigintillion'),
    _(u'quinquatrigintillion'),
    _(u'sestrigintillion'),
    _(u'septentrigintillion'),
    _(u'octotrigintillion'),
    _(u'novemtrigintillion'),
    _(u'quadragintillion'),
)
# natural.file
FILESIZE_SUFFIX = dict(
    decimal=('B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'),
    binary=('iB', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB', 'YiB'),
    gnu='BKMGTPEZY',
)
# natural.data
PRINTABLE = map(lambda c: chr(c), xrange(0x20, 0x7f))
SPARKCHAR = u'\u2581\u2582\u2583\u2584\u2585\u2586\u2587\u2588'
# natural.spelling
SPELL_ALPHABET = {
    u'a': _(u'Amsterdam'),
    u'ä': _(u'ä'),          # There is no en_US entry for this
    u'b': _(u'Baltimore'),
    u'c': _(u'Casablanca'),
    u'd': _(u'Danmark'),
    u'e': _(u'Edison'),
    u'f': _(u'Florida'),
    u'g': _(u'Gallipoli'),
    u'h': _(u'Havanna'),
    u'i': _(u'Italia'),
    u'j': _(u'Jerusalem'),
    u'k': _(u'Kilogramme'),
    u'l': _(u'Liverpool'),
    u'm': _(u'Madagaskar'),
    u'n': _(u'New York'),
    u'ñ': _(u'ñ'),          # There is no en_US entry for this
    u'o': _(u'Oslo'),
    u'ö': _(u'ö'),          # There is no en_US entry for this
    u'p': _(u'Paris'),
    u'q': _(u'Québec'),
    u'r': _(u'Roma'),
    u's': _(u'Santiago'),
    u't': _(u'Tripoli'),
    u'u': _(u'Uppsala'),
    u'ü': _(u'ü'),          # There is no en_US entry for this
    u'v': _(u'Valencia'),
    u'w': _(u'Washington'),
    u'x': _(u'Xantippe'),
    u'y': _(u'Yokohama'),
    u'z': _(u'Zürich'),
}
NATO_ALPHABET = {
    '0': 'zero',
    '1': 'one',
    '2': 'two',
    '3': 'three',
    '4': 'four',
    '5': 'five',
    '6': 'six',
    '7': 'seven',
    '8': 'eight',
    '9': 'nine',
    'a': 'alpha',
    'b': 'bravo',
    'c': 'charlie',
    '-': 'dash',
    'd': 'delta',
    'e': 'echo',
    'f': 'foxtrot',
    'g': 'golf',
    'h': 'hotel',
    'i': 'india',
    'j': 'juliet',
    'k': 'kilo',
    'l': 'lima',
    'm': 'mike',
    'n': 'november',
    'o': 'oscar',
    'p': 'papa',
    'q': 'quebec',
    'r': 'romeo',
    's': 'sierra',
    '.': 'stop',
    't': 'tango',
    'u': 'uniform',
    'v': 'victor',
    'w': 'whiskey',
    'x': 'xray',
    'y': 'yankee',
    'z': 'zulu',
}
NATO_ALPHABET_PHONETIC = {
    '0': 'zee-ro',
    '1': 'wun',
    '2': 'too',
    '3': 'tree',
    '4': 'fow-er',
    '5': 'fife',
    '6': 'six',
    '7': 'sev-en',
    '8': 'ait',
    '9': 'nin-er',
    'a': 'alf-ah',
    'b': 'brah-voh',
    'c': 'char-lee',
    '-': 'das',
    'd': 'dell-tah',
    'e': 'eck-oh',
    'f': 'foks-trot',
    'g': 'golf',
    'h': 'hoh-tel',
    'i': 'in-dee-ah',
    'j': 'jew-lee-ett',
    'k': 'key-loh',
    'l': 'lee-mah',
    'm': 'mike',
    'n': 'no-vem-ber',
    'o': 'oss-cah',
    'p': 'pah-pah',
    'q': 'keh-beck',
    'r': 'row-me-oh',
    's': 'see-air-rah',
    '.': 'stop',
    't': 'tang-go',
    'u': 'you-nee-form',
    'v': 'vic-tah',
    'w': 'wiss-key',
    'x': 'ecks-ray',
    'y': 'yang-key',
    'z': 'zoo-loo',
}
CODE_ALPHABET_ARMY = (u'  ', {
    '0': 'ZE roo',
    '1': 'OO nah wun',
    '2': 'BEES soh too',
    '3': 'TAY rah tree',
    '4': 'KAR tay fower',
    '5': 'PAN tah five',
    '6': 'SOK see six',
    '7': 'SAY tay seven',
    '8': 'OK toh eight',
    '9': 'NO vay niner',
    'a': 'AL fah',
    'b': 'BRAH voh',
    'c': 'CHAR lee',
    '-': 'DASH',
    'd': 'DEL tah',
    'e': 'EKK oh',
    'f': 'FOKS trot',
    'g': 'Golf',
    'h': 'HO tell',
    'i': 'IN dee ah',
    'j': 'JEW lee ett',
    'k': 'KEY loh',
    'l': 'LEE mah',
    'm': 'Mike',
    'n': 'NOH vem ber',
    'o': 'OSS car',
    'p': 'PAH pah',
    'q': 'keh BECK',
    'r': 'ROW me oh',
    's': 'see AIR ah',
    '.': 'STOP',
    't': 'TANG go',
    'u': 'YOU nee form',
    'v': 'VIK ter',
    'w': 'WISS key',
    'x': 'EKS ray',
    'y': 'YANG kee',
    'z': 'ZOO loo',
})
CODE_ALPHABET_FAA = (u' ', {
    '0': 'ZERO',
    '1': 'WUN',
    '2': 'TOO',
    '3': 'TREE',
    '4': 'FOW ER',
    '5': 'FIFE',
    '6': 'SIX',
    '7': 'SEV EN',
    '8': 'AIT',
    '9': 'NIN ER',
    'a': 'ALFAH',
    'b': 'BRAHVOH',
    'c': 'CHARLEE',
    'd': 'DELLTAH',
    'e': 'ECKOH',
    'f': 'FOKSTROT',
    'g': 'GOLF',
    'h': 'HOHTELL',
    'i': 'INDEE AH',
    'j': 'JEWLEE ETT',
    'k': 'KEYLOH',
    'l': 'LEEMAH',
    'm': 'MIKE',
    'n': 'NOVEMBER',
    'o': 'OSSCAH',
    'p': 'PAHPAH',
    'q': 'KEHBECK',
    'r': 'ROWME OH',
    's': 'SEEAIRAH',
    '.': 'STOP',
    't': 'TANGGO',
    'u': 'YOUNEE FORM',
    'v': 'VIKTAH',
    'w': 'WISSKEY',
    'x': 'ECKSRAY',
    'y': 'YANGKEY',
    'z': 'ZOOLOO',
})
CODE_ALPHABET_ICAO = (u'  ', {
    '0': 'ZE RO',
    '1': 'OO NAH WUN',
    '2': 'TOO',
    '3': 'TREE',
    '4': 'FOW ER',
    '5': 'FIFE',
    '6': 'SIX',
    '7': 'SEVEN',
    '8': 'AIT',
    '9': 'NIN ER',
    'a': 'AL FAH',
    'b': 'BRAH VOH',
    'c': 'CHAR LEE',
    'd': 'DELL TAH',
    'e': 'ECK OH',
    'f': 'FOKS TROT',
    'g': 'GOLF',
    'h': 'HOH TELL',
    'i': 'IN DEE AH',
    'j': 'JEW LEE ETT',
    'k': 'KEY LOH',
    'l': 'LEE MAH',
    'm': 'MIKE',
    'n': 'NO VEM BER',
    'o': 'OSS CAH',
    'p': 'PAH PAH',
    'q': 'KEH BECK',
    'r': 'ROW ME OH',
    's': 'SEE AIR RAH',
    '.': 'STOP',
    't': 'TANG GO',
    'u': 'YOU NEE FORM',
    'v': 'VIK TAH',
    'w': 'WISS KEY',
    'x': 'ECKS RAY',
    'y': 'YANG KEY',
    'z': 'ZOO LOO',
})
CODE_ALPHABET_MORSE = (u' ', {
    '=': '-...-',
    ' ': '/',
    '_': '..--.-',
    '-': '-....-',
    ',': '--..--',
    ';': '-.-.-.',
    ':': '---...',
    '!': '-.-.--',
    '?': '..--..',
    '/': '-..-.',
    '.': '.-.-.-',
    '"': '.-..-.',
    '(': '-.--.',
    ')': '-.--.-',
    '$': '..._.._',
    '&': '.-...',
    '+': '.-.-.',
    "'": '.----.',
    '0': '-----',
    '1': '.----',
    '2': '..---',
    '3': '...--',
    '4': '....-',
    '5': '.....',
    '6': '-....',
    '7': '--...',
    '8': '---..',
    '9': '----.',
    'a': '.-',
    '@': '.--.-.',      # A + C
    'b': '-...',
    'c': '-.-.',
    'd': '-..',
    'e': '.',
    'f': '..-.',
    'g': '--.',
    'h': '....',
    'i': '..',
    'j': '.---',
    'k': '-.-',
    'l': '.-..',
    'm': '--',
    'n': '-.',
    'o': '---',
    'p': '.--.',
    'q': '--.-',
    'r': '.-.',
    's': '...',
    't': '-',
    'u': '..-',
    'v': '...-',
    'w': '.--',
    'x': '-..-',
    'y': '-.--',
    'z': '--..',
})
CODE_ALPHABET_WORD = (u' ', {
    '0': 'zero',
    '1': 'one',
    '2': 'two',
    '3': 'three',
    '4': 'four',
    '5': 'five',
    '6': 'six',
    '7': 'seven',
    '8': 'eight',
    '9': 'nine',
    'a': 'alfa',
    'b': 'bravo',
    'c': 'charlie',
    '-': 'dash',
    'd': 'delta',
    'e': 'echo',
    'f': 'foxtrot',
    'g': 'golf',
    'h': 'hotel',
    'i': 'india',
    'j': 'juliett',
    'k': 'kilo',
    'l': 'lima',
    'm': 'mike',
    'n': 'november',
    'o': 'oscar',
    'p': 'papa',
    'q': 'quebec',
    'r': 'romeo',
    's': 'sierra',
    '.': 'stop',
    't': 'tango',
    'u': 'uniform',
    'v': 'victor',
    'w': 'whiskey',
    'x': 'x-ray',
    'y': 'yankee',
    'z': 'zulu',
})
CODE_PRONOUNCIATION = {
    '0': _(u'ˈzɛroʊ'),
    '1': _(u'ˈwʌn'),
    '2': _(u'ˈtuː'),
    '3': _(u'ˈtriː'),
    '4': _(u'ˈfoʊ.ər'),
    '5': _(u'ˈfaɪf'),
    '6': _(u'ˈsɪks'),
    '7': _(u'ˈsɛvɛn'),
    '8': _(u'ˈeɪt'),
    '9': _(u'ˈnaɪnər'),
    'a': _(u'ælfɑ'),
    'b': _(u'ˈbrɑːˈvo'),
    'c': _(u'ˈtʃɑːli'),
    'd': _(u'ˈdeltɑ '),
    'e': _(u'ˈeko'),
    'f': _(u'ˈfɔkstrɔt'),
    'g': _(u'ɡʌlf'),
    'h': _(u'hoːˈtel'),
    'i': _(u'ˈindiˑɑ'),
    'j': _(u'ˈdʒuːliˑˈet'),
    'k': _(u'ˈkiːlo'),
    'l': _(u'ˈliːmɑ'),
    'm': _(u'mɑik'),
    'n': _(u'noˈvembə'),
    'o': _(u'ˈɔskɑ'),
    'p': _(u'pəˈpɑ'),
    'q': _(u'keˈbek'),
    'r': _(u'ˈroːmiˑo'),
    's': _(u'siˈerɑ'),
    't': _(u'ˈtænɡo'),
    '.': _(u'ˈstɒp'),
    'u': _(u'ˈjuːnifɔːm'),
    'v': _(u'ˈviktɑ'),
    'w': _(u'ˈwiski'),
    'x': _(u'ˈeksˈrei'),
    'y': _(u'ˈjænki'),
    'z': _(u'ˈzuːluː'),
}


def _multi(singular, plural, count):
    if count == 1:
        return singular
    else:
        return plural



#!/usr/bin/env python

from distutils.core import setup

setup(name='natural',
    version='0.1.1',
    description='Convert data to their natural (human-readable) format',
    long_description='''
Example Usage
=============

Basic usage::

    >>> from natural.file import accessed
    >>> print accessed(__file__)
    just now

We speak your language (with `your support`_)::

    >>> import locale
    >>> locale.setlocale(locale.LC_MESSAGES, 'nl_NL')
    >>> print accessed(__file__)
    zojuist

Bugs/Features
=============

You can issue a ticket in GitHub: https://github.com/tehmaze/natural/issues

Documentation
=============

The project documentation can be found at http://natural.rtfd.org/

.. _your support: http://natural.readthedocs.org/en/latest/locales.html
''',
    author='Wijnand Modderman-Lenstra',
    author_email='maze@pyth0n.org',
    license='MIT',
    keywords='natural data date file number size',
    url='https://github.com/tehmaze/natural',
    packages=['natural'],
    package_data={'natural': ['locale/*/LC_MESSAGES/*.mo']},
)
